@@ -1441,16 +1441,14 @@ sub preprocess_file {
   # strip UTF-8 BOM if it exists - this just makes T::B complain about junk characters
   $buf =~ s/\A\x{feff}//;
 
+  # A MAC (CR only) format file with a comment in the first line will confuse
+  # Text::BibTeX as it will just see one comment line and find no entries
+  # So, if we find an initial comment line with a carriage return at the end, remove it.
+  $buf =~ s/\A\s*\%[^\r]+\r//ms;
+
   File::Slurper::write_text($ufilename, NFC($buf));# Unicode NFC boundary
 
-  my $lbuf = NFD(File::Slurper::read_text($ufilename));# Unicode NFD boundary
-
-  # Always decode LaTeX to UTF8
-  $logger->info('Decoding LaTeX character macros into UTF-8');
-  if ($logger->is_trace()) {# performance tune
-    $logger->trace("Buffer before decoding -> '$lbuf'");
-  }
-  $lbuf = Biber::LaTeX::Recode::latex_decode($lbuf);
+  my $lbuf = parse_decode($ufilename);
 
   if ($logger->is_trace()) {# performance tune
     $logger->trace("Buffer after decoding -> '$lbuf'");
@@ -1461,6 +1459,64 @@ sub preprocess_file {
   return $ufilename;
 }
 
+=head2 parse_decode
+
+  Partially parse the .bib datasource and latex_decode the data contents.
+  We do this because latex_decoding the entire buffer is difficult since
+  such decoding is regexp based and since braces are used to protect data in
+  .bib files, it makes it hard to do some parsing.
+
+=cut
+
+sub parse_decode {
+  my $ufilename = shift;
+  my $dmh = Biber::Config->get_dm_helpers;
+  my $lbuf;
+
+  my $bib = Text::BibTeX::File->new();
+  $bib->open($ufilename, {binmode => 'utf-8', normalization => 'NFD'}) or biber_error("Cannot create Text::BibTeX::File object from $ufilename: $!");
+
+  $logger->info("LaTeX decoding ...");
+
+  while ( my $entry = Text::BibTeX::Entry->new($bib) ) {
+    if ( $entry->metatype == BTE_REGULAR ) {
+      $lbuf .= '@' . $entry->type . '{' . $entry->key . ',' . "\n";
+      foreach my $f ($entry->fieldlist) {
+        my $fv = $entry->get($f);
+
+        # Don't decode verbatim fields
+        if (not first {fc($f) eq fc($_)} $dmh->{verbs}->@*) {
+          $fv = Biber::LaTeX::Recode::latex_decode($fv);
+        }
+        $lbuf .= "  $f = {$fv},\n";
+      }
+      $lbuf .= "\n" . '}' . "\n\n";
+    }
+    elsif ($entry->metatype == BTE_PREAMBLE) {
+      $lbuf .= '@PREAMBLE{"' . Biber::LaTeX::Recode::latex_decode($entry->value) . '"}' . "\n";
+    }
+    elsif ($entry->metatype == BTE_COMMENT) {
+      $lbuf .= '@COMMENT{' . Biber::LaTeX::Recode::latex_decode($entry->value) . '}' . "\n";
+    }
+    elsif ($entry->metatype == BTE_MACRODEF) {
+      $lbuf .= '@STRING{';
+      foreach my $f ($entry->fieldlist) {
+        $lbuf .= $f . ' = {' . Biber::LaTeX::Recode::latex_decode($entry->get($f)) . '}';
+      }
+      $lbuf .= "}\n";
+    }
+    else {
+      $lbuf .= Biber::LaTeX::Recode::latex_decode($entry->print_s);
+    }
+  }
+
+  # We will read in the same .bib again later to do the real parsing
+  # and since macro defs are global, need to reset them to avoid redef warnings
+  Text::BibTeX::delete_all_macros();
+
+  return $lbuf;
+}
+
 =head2 parsename
 
     Given a name string, this function returns a Biber::Entry::Name object
